@@ -39,7 +39,7 @@ class EtreeTransform:
         return self._convert_response(response)
 
 
-def _check_command_status(root: etree.Element):
+def check_command_status(root: etree.Element):
     status = root.get("status")
 
     if status is None:
@@ -50,9 +50,7 @@ def _check_command_status(root: etree.Element):
     elif status[0] == "5":
         raise GvmServerError(status=status, message=root.get("status_text"))
     elif status[0] != "2":
-        raise GvmError(
-            "Error in response. {0}".format(root.get("status_text")), root
-        )
+        raise GvmError(f"Error in response. {root.get('status_text')}", root)
 
 
 class CheckCommandTransform(EtreeTransform):
@@ -64,7 +62,7 @@ class CheckCommandTransform(EtreeTransform):
     def __call__(self, response: str) -> str:
         root = self._convert_response(response)
 
-        _check_command_status(root)
+        check_command_status(root)
 
         return response
 
@@ -78,6 +76,6 @@ class EtreeCheckCommandTransform(EtreeTransform):
     def __call__(self, response: str) -> etree.Element:
         root = self._convert_response(response)
 
-        _check_command_status(root)
+        check_command_status(root)
 
         return root
