@@ -17,6 +17,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import unittest
+from unittest.mock import patch
 
 import os
 import socketserver
@@ -35,7 +36,7 @@ from gvm.errors import GvmError
 class DummyRequestHandler(socketserver.BaseRequestHandler):
     def handle(self):
         response = bytes(
-            "<gmp_response status=\"200\" status_text=\"OK\"/>", 'utf-8'
+            '<gmp_response status="200" status_text="OK"/>', 'utf-8'
         )
         self.request.sendall(response)
 
@@ -47,12 +48,9 @@ class ThreadedUnixStreamServer(
 
 
 class UnixSocketConnectionTestCase(unittest.TestCase):
-    # pylint: disable=protected-access
+    # pylint: disable=protected-access, invalid-name
     def setUp(self):
-        self.socketname = "%s/%s.sock" % (
-            tempfile.gettempdir(),
-            str(uuid.uuid4()),
-        )
+        self.socketname = f"{tempfile.gettempdir()}/{str(uuid.uuid4())}.sock"
         self.sockserv = ThreadedUnixStreamServer(
             self.socketname, DummyRequestHandler
         )
@@ -68,37 +66,61 @@ class UnixSocketConnectionTestCase(unittest.TestCase):
         os.unlink(self.socketname)
 
     def test_unix_socket_connection_connect_read(self):
-        self.connection = UnixSocketConnection(
+        connection = UnixSocketConnection(
             path=self.socketname, timeout=DEFAULT_TIMEOUT
         )
-        self.connection.connect()
-        self.connection.read()
-        self.connection.disconnect()
+        connection.connect()
+        resp = connection.read()
+        self.assertEqual(resp, '<gmp_response status="200" status_text="OK"/>')
+        connection.disconnect()
 
     def test_unix_socket_connection_connect_send_bytes_read(self):
-        self.connection = UnixSocketConnection(
+        connection = UnixSocketConnection(
             path=self.socketname, timeout=DEFAULT_TIMEOUT
         )
-        self.connection.connect()
-        self.connection.send(bytes("<gmp/>", 'utf-8'))
-        self.connection.read()
-        self.connection.disconnect()
+        connection.connect()
+        req = connection.send(bytes("<gmp/>", 'utf-8'))
+        self.assertIsNone(req)
+        resp = connection.read()
+        self.assertEqual(resp, '<gmp_response status="200" status_text="OK"/>')
+        connection.disconnect()
 
     def test_unix_socket_connection_connect_send_str_read(self):
-        self.connection = UnixSocketConnection(
+        connection = UnixSocketConnection(
             path=self.socketname, timeout=DEFAULT_TIMEOUT
         )
-        self.connection.connect()
-        self.connection.send("<gmp/>")
-        self.connection.read()
-        self.connection.disconnect()
+        connection.connect()
+        req = connection.send("<gmp/>")
+        self.assertIsNone(req)
+        resp = connection.read()
+        self.assertEqual(resp, '<gmp_response status="200" status_text="OK"/>')
+        connection.disconnect()
+
+    def test_unix_socket_connect_file_not_found(self):
+        connection = UnixSocketConnection(path="foo", timeout=DEFAULT_TIMEOUT)
+        with self.assertRaises(GvmError, msg='Socket foo does not exist'):
+            connection.connect()
+        connection.disconnect()
+
+    def test_unix_socket_connect_could_not_connect(self):
+        connection = UnixSocketConnection(
+            path=self.socketname, timeout=DEFAULT_TIMEOUT
+        )
+        with patch('socket.socket.connect') as ConnectMock:
+            connect_mock = ConnectMock
+            connect_mock.side_effect = ConnectionError
+            with self.assertRaises(
+                GvmError, msg=f'Could not connect to socket {self.socketname}'
+            ):
+                connection.connect()
+            connection.disconnect()
 
     def test_unix_socket_send_unconnected_socket(self):
-        self.connection = UnixSocketConnection(
+        connection = UnixSocketConnection(
             path=self.socketname, timeout=DEFAULT_TIMEOUT
         )
-        with self.assertRaises(GvmError):
-            self.connection.send("<gmp>/")
+        with self.assertRaises(GvmError, msg='Socket is not connected'):
+            connection.send("<gmp>/")
 
     def test_init_no_args(self):
         connection = UnixSocketConnection()
