@@ -26,7 +26,7 @@ from gvm.transforms import EtreeTransform
 class EtreeTransformTestCase(unittest.TestCase):
     def test_transform_response(self):
         transform = EtreeTransform()
-        result = transform('<foo/')
+        result = transform('<foo/>')
 
         self.assertTrue(etree.iselement(result))
 
